==> noahs-2.0.0.tar.gz: noahs/includes/controls/noahs-image-mask.php <==
<?php 

namespace Drupal\noahs_page_builder;

use Drupal\file\Entity\File;
use Drupal\image\Entity\ImageStyle;
use \Drupal\noahs_page_builder_pro\Controller\NoahsMaskImageProController;

class Control_Noahs_Image_Mask{
	
	public function get_type() {
		return 'noahs_image_mask';
	}

	public function content_template($data, $name, $value) {
		$id = $data['wid'];
		$items = NoahsMaskImageProController::list($name);
	
		$options = array(
			'' => 'Auto',
			'cover' => 'Cover',
			'contain' => 'Contain',
			'initial' => 'Custom',
		);
	
		$output = '';
	
		$output .= '<div class="media-preview-actions media-preview-actions--mask overflow-auto mb-3" style="height:200px">';
		$output .= '<div class="row gap-3">';
		foreach ($items as $k => $item) {
			$checked = ($item === $value['mask']) ? 'checked' : '';
			$output .= '<div class="col-2 d-flex align-items-center">';
			$output .= '<label for="mask-' . $k . '">';
			$output .= '<input type="radio" id="mask-' . $k . '" name="' . $name . '[mask]" value="' . $item . '" ' . $checked . ' field-setting>';
			$output .= '<img src="' . $item . '" alt="SVG Image" class="w-100">';
			$output .= '</label>';
			$output .= '</div>';
		}
		$output .= '</div>';
		$output .= '<div class="btn-group position-absolute d-flex justify-content-between w-100">';
		$output .= '<button class="btn btn-danger media-remove_mask_image area_tooltip" title=""><i class="fa-solid fa-trash"></i></button>';
		$output .= '</div>';
		$output .= '</div>';
	
		$output .= '<div class="mb-3">';
		$output .= '<label class="form-label">Mask Size (usep px, %, rem, wv...)</label>';
		$output .= '<select name="' . $name . '[mask_size]" class="form-control" field-setting>';
		foreach ($options as $key => $label) {
			$selected = ($value['mask_size'] === $key) ? 'selected' : '';
			$output .= '<option value="' . $key . '" ' . $selected . '>' . $label . '</option>';
		}
		$output .= '</select>';
		$output .= '</div>';
	
		return $output;
	}
	

	protected function get_default_settings() {
		return [
			'input_type' => 'noahs_image_mask',
			'placeholder' => '',
			'title' => '',
		];
	}
}

==> noahs-2.0.5.tar.gz: noahs/includes/controls/noahs-image-mask.php <==
<?php 

namespace Drupal\noahs_page_builder;

use Drupal\file\Entity\File;
use Drupal\image\Entity\ImageStyle;
use \Drupal\noahs_page_builder_pro\Controller\NoahsMaskImageProController;

class Control_Noahs_Image_Mask{
	
	public function get_type() {
		return 'noahs_image_mask';
	}

	public function content_template($data, $name, $value) {
		$id = $data['wid'];
		$items = NoahsMaskImageProController::list($name);
	
		$options = array(
			'' => 'Auto',
			'cover' => 'Cover',
			'contain' => 'Contain',
			'initial' => 'Custom',
		);
	
		$output = '';
	
		$output .= '<div class="media-preview-actions media-preview-actions--mask overflow-auto mb-3" style="height:200px">';
		$output .= '<div class="row gap-3">';
		foreach ($items as $k => $item) {
			$checked = (!empty($value['mask_size']) && $item === $value['mask']) ? 'checked' : '';
			$output .= '<div class="col-2 d-flex align-items-center">';
			$output .= '<label for="mask-' . $k . '">';
			$output .= '<input type="radio" id="mask-' . $k . '" name="' . $name . '[mask]" value="' . $item . '" ' . $checked . ' field-setting>';
			$output .= '<img src="' . $item . '" alt="SVG Image" class="w-100">';
			$output .= '</label>';
			$output .= '</div>';
		}
		$output .= '</div>';
		$output .= '<div class="btn-group position-absolute d-flex justify-content-between w-100">';
		$output .= '<button class="btn btn-danger media-remove_mask_image area_tooltip" title=""><i class="fa-solid fa-trash"></i></button>';
		$output .= '</div>';
		$output .= '</div>';
	
		$output .= '<div class="mb-3">';
		$output .= '<label class="form-label">Mask Size (usep px, %, rem, wv...)</label>';
		$output .= '<select name="' . $name . '[mask_size]" class="form-control" field-setting>';
		foreach ($options as $key => $label) {
			$selected = (!empty($value['mask_size']) && $value['mask_size'] === $key) ? 'selected' : '';
			$output .= '<option value="' . $key . '" ' . $selected . '>' . $label . '</option>';
		}
		$output .= '</select>';
		$output .= '</div>';
	
		return $output;
	}
	

	protected function get_default_settings() {
		return [
			'input_type' => 'noahs_image_mask',
			'placeholder' => '',
			'title' => '',
		];
	}
}
